@@ -3,14 +3,20 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from lusid.api.address_key_definition_api import AddressKeyDefinitionApi
 from lusid.api.aggregation_api import AggregationApi
 from lusid.api.allocations_api import AllocationsApi
 from lusid.api.application_metadata_api import ApplicationMetadataApi
+from lusid.api.blocks_api import BlocksApi
 from lusid.api.calendars_api import CalendarsApi
 from lusid.api.complex_market_data_api import ComplexMarketDataApi
+from lusid.api.compliance_api import ComplianceApi
 from lusid.api.configuration_recipe_api import ConfigurationRecipeApi
 from lusid.api.corporate_action_sources_api import CorporateActionSourcesApi
 from lusid.api.counterparties_api import CounterpartiesApi
+from lusid.api.custom_entities_api import CustomEntitiesApi
+from lusid.api.custom_entity_definitions_api import CustomEntityDefinitionsApi
+from lusid.api.custom_entity_types_api import CustomEntityTypesApi
 from lusid.api.cut_label_definitions_api import CutLabelDefinitionsApi
 from lusid.api.data_types_api import DataTypesApi
 from lusid.api.derived_transaction_portfolios_api import DerivedTransactionPortfoliosApi
@@ -18,18 +24,26 @@ from lusid.api.entities_api import EntitiesApi
 from lusid.api.executions_api import ExecutionsApi
 from lusid.api.instruments_api import InstrumentsApi
 from lusid.api.legal_entities_api import LegalEntitiesApi
+from lusid.api.order_graph_api import OrderGraphApi
+from lusid.api.order_management_api import OrderManagementApi
 from lusid.api.orders_api import OrdersApi
+from lusid.api.participations_api import ParticipationsApi
 from lusid.api.persons_api import PersonsApi
+from lusid.api.placements_api import PlacementsApi
 from lusid.api.portfolio_groups_api import PortfolioGroupsApi
 from lusid.api.portfolios_api import PortfoliosApi
 from lusid.api.property_definitions_api import PropertyDefinitionsApi
 from lusid.api.quotes_api import QuotesApi
 from lusid.api.reconciliations_api import ReconciliationsApi
+from lusid.api.reference_lists_api import ReferenceListsApi
 from lusid.api.reference_portfolio_api import ReferencePortfolioApi
 from lusid.api.relationship_definitions_api import RelationshipDefinitionsApi
 from lusid.api.relationships_api import RelationshipsApi
+from lusid.api.schemas_api import SchemasApi
 from lusid.api.scopes_api import ScopesApi
+from lusid.api.scripted_translation_api import ScriptedTranslationApi
 from lusid.api.search_api import SearchApi
 from lusid.api.sequences_api import SequencesApi
+from lusid.api.structured_result_data_api import StructuredResultDataApi
 from lusid.api.system_configuration_api import SystemConfigurationApi
 from lusid.api.transaction_portfolios_api import TransactionPortfoliosApi
